<?php

namespace App\Controller\OgBoot\OgLive;

use App\Controller\OgBoot\AbstractOgLiveController;
use App\Entity\OgLive;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

#[AsController]
class SetDefaultAction extends AbstractOgLiveController
{
    /**
     * @throws TransportExceptionInterface
     * @throws ServerExceptionInterface
     * @throws RedirectionExceptionInterface
     * @throws ClientExceptionInterface
     */
    public function __invoke(OgLive $data, HttpClientInterface $httpClient,  EntityManagerInterface $entityManager): JsonResponse
    {
        try {
            $response = $httpClient->request('PUT', $this->ogBootApiUrl.'/ogboot/v1/oglives/default', [
                'headers' => [
                    'accept' => 'application/json',
                ],
                'json' => [
                    'checksum' => $data->getChecksum()
                ]
            ]);
        } catch (TransportExceptionInterface $e) {
            return new JsonResponse( data: 'An error occurred', status: Response::HTTP_INTERNAL_SERVER_ERROR);
        }

        if ($response->getStatusCode() === Response::HTTP_OK) {
            $data->setIsDefault(true);
            $entityManager->persist($data);
            $entityManager->flush();
        }

        $data = json_decode($response->getContent(), true);

        return new JsonResponse( data: $data, status: Response::HTTP_OK);
    }
}