<?php

namespace App\Controller\OgBoot\OgLive;

use App\Controller\OgBoot\AbstractOgLiveController;
use App\Entity\OgLive;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

#[AsController]
class SyncAction extends AbstractOgLiveController
{
    /**
     * @throws TransportExceptionInterface
     * @throws ServerExceptionInterface
     * @throws RedirectionExceptionInterface
     * @throws ClientExceptionInterface
     */
    public function __invoke(HttpClientInterface $httpClient, EntityManagerInterface $entityManager): JsonResponse
    {
        try {
            $response = $httpClient->request('GET', $this->ogBootApiUrl.'/ogboot/v1/oglives', [
                'headers' => [
                    'accept' => 'application/json',
                ],
            ]);

        } catch (TransportExceptionInterface $e) {
            return new JsonResponse( data: 'An error occurred', status: Response::HTTP_INTERNAL_SERVER_ERROR);
        }

        $data = json_decode($response->getContent(), true);

        foreach ($data['installed_ogLives'] as $ogLive) {
            $ogLiveEntity = $this->entityManager->getRepository(OgLive::class)->findOneBy(['checksum' => $ogLive['id']]);
            if ($ogLiveEntity) {
                $ogLiveEntity->setName($ogLive['filename']);
                $ogLiveEntity->setInstalled(true);
                $ogLiveEntity->setArchitecture($ogLive['architecture']);
                $ogLiveEntity->setKernel($ogLive['kernel']);
                $ogLiveEntity->setRevision($ogLive['revision']);
                $ogLiveEntity->setDirectory($ogLive['directory']);
                $ogLiveEntity->setChecksum($ogLive['id']);
                $this->entityManager->persist($ogLiveEntity);
            } else {
                $ogLiveEntity = new OgLive();
                $ogLiveEntity->setName($ogLive['filename']);
                $ogLiveEntity->setInstalled(true);
                $ogLiveEntity->setArchitecture($ogLive['architecture']);
                $ogLiveEntity->setKernel($ogLive['kernel']);
                $ogLiveEntity->setRevision($ogLive['revision']);
                $ogLiveEntity->setDirectory($ogLive['directory']);
                $ogLiveEntity->setChecksum($ogLive['id']);
            }
            $this->entityManager->persist($ogLiveEntity);

        }

        $this->entityManager->flush();

        return new JsonResponse( data: $data, status: Response::HTTP_OK);
    }
}