<?php

namespace App\Controller\OgBoot\OgLive;

use App\Controller\OgBoot\AbstractOgLiveController;
use App\Entity\OgLive;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

#[AsController]
class UninstallAction extends AbstractOgLiveController
{
    /**
     * @throws ServerExceptionInterface
     * @throws RedirectionExceptionInterface
     * @throws ClientExceptionInterface
     * @throws TransportExceptionInterface
     */
    public function __invoke(OgLive $data, HttpClientInterface $httpClient, EntityManagerInterface $entityManager): JsonResponse
    {
        try {
            $response = $httpClient->request('DELETE', $this->ogBootApiUrl.'/ogboot/v1/oglives/'.$data->getChecksum(), [
                'headers' => [
                    'accept' => 'application/json',
                ],
            ]);

        } catch (TransportExceptionInterface $e) {
            return new JsonResponse( data: $e->getMessage(), status: Response::HTTP_INTERNAL_SERVER_ERROR);
        }

        if ($response->getStatusCode() === Response::HTTP_OK) {
            $data->setInstalled(false);
            $entityManager->persist($data);
            $entityManager->flush();
        }

        return new JsonResponse(status: Response::HTTP_OK);
    }
}